@@ -2,7 +2,7 @@ package Mojolicious::Plugin::ReplyTable;
 
 use Mojo::Base 'Mojolicious::Plugin';
 
-our $VERSION = '0.09';
+our $VERSION = '0.10';
 $VERSION = eval $VERSION;
 
 use Mojo::Util;
@@ -38,7 +38,8 @@ sub _to_csv {
   require Text::CSV;
   my $csv_options = $c->stash('reply_table.csv_options') || {};
   $csv_options->{binary} = 1 unless exists $csv_options->{binary};
-  my $csv = Text::CSV->new($csv_options);
+  my $csv = Text::CSV->new($csv_options)
+    or die Text::CSV->error_diag();
   my $string = '';
   for my $row (@$data) {
     $csv->combine(@$row) || die $csv->error_diag;
@@ -249,6 +250,8 @@ Nils Diewald (Akron)
 
 Ryan Perry
 
+Ilya Chesnokov (ichesnokov)
+
 =back
 
 =head1 COPYRIGHT AND LICENSE
